@@ -6,6 +6,7 @@ from typing import (
     AsyncGenerator,
     Callable,
     Generator,
+    Tuple,
     Union,
     no_type_check,
     no_type_check_decorator,
@@ -194,3 +195,21 @@ def aug_assign() -> int:
     x: int = 1
     x += 1
     return x
+
+
+@typechecked
+def unpacking_assign() -> Tuple[int, str]:
+    x: int
+    x, y = (1, "foo")
+    return x, y
+
+
+@typechecked
+def unpacking_assign_generator() -> Tuple[int, str]:
+    def genfunc():
+        yield 1
+        yield "foo"
+
+    x: int
+    x, y = genfunc()
+    return x, y
